@@ -96,8 +96,7 @@ def seleziona_colonne(df, lista_colonne):
 
 #make function to apply sql query on dataframe
 def esegui_query(df, query):
-    return(df.query(query))
-
+    return(pd.read_sql(query, df))
 
 
 
